Mailinglist Archive: radeonhd (622 mails)
| < Previous | Next > |
[radeonhd] [PATCH] Spelling fix: separate
- From: Jean Delvare <jdelvare@xxxxxxx>
- Date: Tue, 9 Oct 2007 16:45:07 +0200
- Message-id: <200710091645.07512.jdelvare@xxxxxxx>
--
Jean Delvare
Suse L3
src/rhd_edid.c | 4 ++--
src/rhd_modes.c | 4 ++--
utils/conntest/README | 2 +-
3 files changed, 5 insertions(+), 5 deletions(-)
--- xf86-video-radeonhd.orig/src/rhd_modes.c
+++ xf86-video-radeonhd/src/rhd_modes.c
@@ -1045,7 +1045,7 @@ rhdModesGrabOnHighestType(DisplayModePtr
if (Mode)
return Mode;
- /* No reason why we should treat built-in and vesa seperately */
+ /* No reason why we should treat built-in and vesa separately */
Mode = *Modes;
*Modes = NULL;
return Mode;
@@ -1336,7 +1336,7 @@ RHDModesPoolCreate(ScrnInfoPtr pScrn, Bo
/* Sort our list */
TempList = Pool;
- /* Sort higher priority modes seperately */
+ /* Sort higher priority modes separately */
Pool = rhdModesGrabOnTypeAll(&TempList, M_T_PREFERRED, M_T_PREFERRED);
Pool = rhdModesSortOnSize(Pool);
--- xf86-video-radeonhd.orig/utils/conntest/README
+++ xf86-video-radeonhd/utils/conntest/README
@@ -76,7 +76,7 @@ support for your card.
Create a small text file. Each step, mention which cable was connected where.
-Go over each connector seperately, and connect the analogue (VGA) cable once
+Go over each connector separately, and connect the analogue (VGA) cable once
and connect the DVI cable once (when possible). Each time running conntest and
saving the data conntest spews out.
| < Previous | Next > |
--- xf86-video-radeonhd.orig/src/rhd_edid.c
+++ xf86-video-radeonhd/src/rhd_edid.c
@@ -116,9 +116,9 @@ EDIDModeFromDetailedTiming(int scrnIndex
return NULL;
}
/* We only do seperate sync currently */
if (timing->sync != 0x03) {
- xf86DrvMsg(scrnIndex, X_INFO, "%s: Ignoring: We only handle seperate"
+ xf86DrvMsg(scrnIndex, X_INFO, "%s: Ignoring: We only handle separate"
" sync.\n", __func__);
return NULL;
}
@@ -116,9 +116,9 @@ EDIDModeFromDetailedTiming(int scrnIndex
return NULL;
}
- /* We only do seperate sync currently */
+ /* We only do separate sync currently */
if (timing->sync != 0x03) {